
(_api_optical)=
# Optical Properties

## Class Objects

```{eval-rst}
.. autosummary::
    :toctree: generated/

    sasktran2.optical.O3DBM
    sasktran2.optical.NO2Vandaele
    sasktran2.optical.HITRANUV
    sasktran2.optical.HITRANAbsorber
    sasktran2.optical.HITRANTabulated
    sasktran2.optical.HITRANCollision
    sasktran2.optical.database.OpticalDatabase
    sasktran2.optical.database.OpticalDatabaseGenericAbsorber
    sasktran2.optical.database.OpticalDatabaseGenericScatterer
    sasktran2.optical.Mie
```

## Special Modules

```{eval-rst}
.. autosummary::
    :toctree: generated/

    sasktran2.optical.rayleigh
```
